#import "MainViewController.h"

@implementation MainViewController

- (void)loadView {
	[super loadView];

	// BitmapView を生成
	bitmapView = [[BitmapView alloc] initWithFrame:self.view.frame];
	bitmapView.backgroundColor = [UIColor grayColor];

	// Bitmap を生成
	bitmap = [[Bitmap alloc] initWithSize:self.view.frame.size];
	[bitmap clearWithColor:[UIColor blackColor]];
	
	// BitmapView に bitmap をひもづけ
	bitmapView.bitmap = bitmap;

	// BitmapView を MainViewController の View にはりつけ
	[self.view addSubview:bitmapView];

	// 消去ボタンを作成
	clearButton = [[UIButton buttonWithType:UIButtonTypeRoundedRect] retain];
	clearButton.frame = CGRectMake(0, 480-44, 44,44);
	[clearButton addTarget:self 
					action:@selector(clearButtonPushed:) 
		  forControlEvents:UIControlEventTouchUpInside];
	[self.view addSubview:clearButton];
	
	// 加速度センサでの検出をonにする。
	// シェイクされると delegate で accelerometerSensorDetected が呼び出される
	[NTLNAccelerometerSensor sharedInstance].delegate = self;
}

- (void)touchesBegan:(NSSet *)touches 
		   withEvent:(UIEvent *)event {
	UITouch *touch = [[touches allObjects] objectAtIndex:0];
	CGPoint pt = [touch locationInView:bitmapView];

	//	NSLog(@"%f, %f", pt.x, pt.y);
	
	lastPt = pt;
}

- (void)touchesMoved:(NSSet *)touches 
		   withEvent:(UIEvent *)event {
	UITouch *touch = [[touches allObjects] objectAtIndex:0];
	CGPoint pt = [touch locationInView:bitmapView];

	//	NSLog(@"%f, %f", pt.x, pt.y);

	[bitmap drawLineFrom:lastPt 
					  to:pt 
				  radius:10.f 
				   color:[UIColor whiteColor]];
	lastPt = pt;
	[bitmapView setNeedsDisplay];
}

- (void)touchesEnded:(NSSet *)touches 
		   withEvent:(UIEvent *)event {
	UITouch *touch = [[touches allObjects] objectAtIndex:0];
	CGPoint pt = [touch locationInView:bitmapView];

	//	NSLog(@"%f, %f", pt.x, pt.y);

	[bitmap drawLineFrom:lastPt 
					  to:pt 
				  radius:10.f 
				   color:[UIColor whiteColor]];
	lastPt = pt;
	[bitmapView setNeedsDisplay];
	
	[bitmap clearWithColor:[UIColor colorWithWhite:0.f alpha:0.3f]];
}

- (void)touchesCancelled:(NSSet *)touches 
			   withEvent:(UIEvent *)event {
}

- (void)clearButtonPushed:(id)sender {
	NSLog(@"clearButtonPushed");

	// bitmapを黒でぬりつぶし
	[bitmap clearWithColor:[UIColor blackColor]];
	[bitmapView setNeedsDisplay];
}

- (void)accelerometerSensorDetected {
	// bitmapを黒でぬりつぶし
	[bitmap clearWithColor:[UIColor blackColor]];
	[bitmapView setNeedsDisplay];
}

- (void)dealloc {
	[NTLNAccelerometerSensor sharedInstance].delegate = nil;
	[bitmapView release];
	[bitmap release];
    [super dealloc];
}

@end
